pub struct GitHubEnterpriseConfig {
pub app_id: Option<i64>,
pub create_time: Option<DateTime<Utc>>,
pub display_name: Option<String>,
pub host_url: Option<String>,
pub name: Option<String>,
pub peered_network: Option<String>,
pub secrets: Option<GitHubEnterpriseSecrets>,
pub ssl_ca: Option<String>,
pub webhook_key: Option<String>,
}Expand description
GitHubEnterpriseConfig represents a configuration for a GitHub Enterprise server.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- github enterprise configs create projects (request)
- github enterprise configs get projects (response)
- github enterprise configs patch projects (request)
- locations github enterprise configs create projects (request)
- locations github enterprise configs get projects (response)
- locations github enterprise configs patch projects (request)
Fields
app_id: Option<i64>Required. The GitHub app id of the Cloud Build app on the GitHub Enterprise server.
create_time: Option<DateTime<Utc>>Output only. Time when the installation was associated with the project.
display_name: Option<String>Optional. Name to display for this config.
host_url: Option<String>The URL of the github enterprise host the configuration is for.
name: Option<String>The full resource name for the GitHubEnterpriseConfig For example: “projects/{$project_id}/locations/{$location_id}/githubEnterpriseConfigs/{$config_id}”
peered_network: Option<String>Optional. The network to be used when reaching out to the GitHub Enterprise server. The VPC network must be enabled for private service connection. This should be set if the GitHub Enterprise server is hosted on-premises and not reachable by public internet. If this field is left empty, no network peering will occur and calls to the GitHub Enterprise server will be made over the public internet. Must be in the format projects/{project}/global/networks/{network}, where {project} is a project number or id and {network} is the name of a VPC network in the project.
secrets: Option<GitHubEnterpriseSecrets>Optional. Names of secrets in Secret Manager.
ssl_ca: Option<String>Optional. SSL certificate to use for requests to GitHub Enterprise.
webhook_key: Option<String>The key that should be attached to webhook calls to the ReceiveWebhook endpoint.