pub struct Results {
pub artifact_manifest: Option<String>,
pub artifact_timing: Option<TimeSpan>,
pub build_step_images: Option<Vec<String>>,
pub build_step_outputs: Option<Vec<Vec<u8>>>,
pub go_modules: Option<Vec<UploadedGoModule>>,
pub images: Option<Vec<BuiltImage>>,
pub maven_artifacts: Option<Vec<UploadedMavenArtifact>>,
pub npm_packages: Option<Vec<UploadedNpmPackage>>,
pub num_artifacts: Option<i64>,
pub python_packages: Option<Vec<UploadedPythonPackage>>,
}Expand description
Artifacts created by the build pipeline.
This type is not used in any activity, and only used as part of another schema.
Fields
artifact_manifest: Option<String>Path to the artifact manifest for non-container artifacts uploaded to Cloud Storage. Only populated when artifacts are uploaded to Cloud Storage.
artifact_timing: Option<TimeSpan>Time to push all non-container artifacts to Cloud Storage.
build_step_images: Option<Vec<String>>List of build step digests, in the order corresponding to build step indices.
build_step_outputs: Option<Vec<Vec<u8>>>List of build step outputs, produced by builder images, in the order corresponding to build step indices. Cloud Builders can produce this output by writing to $BUILDER_OUTPUT/output. Only the first 50KB of data is stored. Note that the $BUILDER_OUTPUT variable is read-only and can’t be substituted.
go_modules: Option<Vec<UploadedGoModule>>Optional. Go module artifacts uploaded to Artifact Registry at the end of the build.
images: Option<Vec<BuiltImage>>Container images that were built as a part of the build.
maven_artifacts: Option<Vec<UploadedMavenArtifact>>Maven artifacts uploaded to Artifact Registry at the end of the build.
npm_packages: Option<Vec<UploadedNpmPackage>>Npm packages uploaded to Artifact Registry at the end of the build.
num_artifacts: Option<i64>Number of non-container artifacts uploaded to Cloud Storage. Only populated when artifacts are uploaded to Cloud Storage.
python_packages: Option<Vec<UploadedPythonPackage>>Python artifacts uploaded to Artifact Registry at the end of the build.