Struct google_cloudbuild1::api::StorageSource [−][src]
Location of the source in an archive file in Google Cloud Storage.
This type is not used in any activity, and only used as part of another schema.
Fields
bucket: Option<String>Google Cloud Storage bucket containing the source (see Bucket Name Requirements).
generation: Option<String>Google Cloud Storage generation for the object. If the generation is omitted, the latest generation will be used.
object: Option<String>Google Cloud Storage object containing the source. This object must be a gzipped archive file (.tar.gz) containing source to build.