Struct google_cloudbuild1::api::Volume [−][src]
Volume describes a Docker container volume which is mounted into build steps in order to persist files across build step execution.
This type is not used in any activity, and only used as part of another schema.
Fields
name: Option<String>Name of the volume to mount. Volume names must be unique per build step and must be valid names for Docker volumes. Each named volume must be used by at least two build steps.
path: Option<String>Path at which to mount the volume. Paths must be absolute and cannot conflict with other volume paths on the same build step or with certain reserved volume paths.