[][src]Struct google_cloudbuild1::RetryBuildRequest

pub struct RetryBuildRequest { /* fields omitted */ }

Specifies a build to retry.

Activities

This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).